# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IAppArgs', 'IApp']

@pulumi.input_type
class IAppArgs:
    def __init__(__self__, *,
                 jsonfile: pulumi.Input[str],
                 name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 devicegroup: Optional[pulumi.Input[str]] = None,
                 execute_action: Optional[pulumi.Input[str]] = None,
                 inherited_devicegroup: Optional[pulumi.Input[str]] = None,
                 inherited_traffic_group: Optional[pulumi.Input[str]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 strict_updates: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableArgs']]]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 template_modified: Optional[pulumi.Input[str]] = None,
                 template_prerequisite_errors: Optional[pulumi.Input[str]] = None,
                 traffic_group: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input['IAppVariableArgs']]]] = None):
        """
        The set of arguments for constructing a IApp resource.
        :param pulumi.Input[str] jsonfile: Refer to the Json file which will be deployed on F5 BIG-IP.
        :param pulumi.Input[str] name: Name of the iApp.
        :param pulumi.Input[str] description: User defined description.
        :param pulumi.Input[str] devicegroup: BIG-IP password
        :param pulumi.Input[str] execute_action: Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        :param pulumi.Input[str] inherited_devicegroup: Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        :param pulumi.Input[str] inherited_traffic_group: Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        :param pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]] lists: string values
        :param pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]] metadatas: User defined generic data for the application service. It is a name and value pair.
        :param pulumi.Input[str] partition: Displays the administrative partition within which the application resides.
        :param pulumi.Input[str] strict_updates: Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        :param pulumi.Input[str] template: The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        :param pulumi.Input[str] template_modified: Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        :param pulumi.Input[str] template_prerequisite_errors: Indicates any missing prerequisites associated with the template that defines this application.
        :param pulumi.Input[str] traffic_group: The name of the traffic group that the application service is assigned to.
        """
        pulumi.set(__self__, "jsonfile", jsonfile)
        pulumi.set(__self__, "name", name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if devicegroup is not None:
            pulumi.set(__self__, "devicegroup", devicegroup)
        if execute_action is not None:
            pulumi.set(__self__, "execute_action", execute_action)
        if inherited_devicegroup is not None:
            pulumi.set(__self__, "inherited_devicegroup", inherited_devicegroup)
        if inherited_traffic_group is not None:
            pulumi.set(__self__, "inherited_traffic_group", inherited_traffic_group)
        if lists is not None:
            pulumi.set(__self__, "lists", lists)
        if metadatas is not None:
            pulumi.set(__self__, "metadatas", metadatas)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if strict_updates is not None:
            pulumi.set(__self__, "strict_updates", strict_updates)
        if tables is not None:
            pulumi.set(__self__, "tables", tables)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if template_modified is not None:
            pulumi.set(__self__, "template_modified", template_modified)
        if template_prerequisite_errors is not None:
            pulumi.set(__self__, "template_prerequisite_errors", template_prerequisite_errors)
        if traffic_group is not None:
            pulumi.set(__self__, "traffic_group", traffic_group)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter
    def jsonfile(self) -> pulumi.Input[str]:
        """
        Refer to the Json file which will be deployed on F5 BIG-IP.
        """
        return pulumi.get(self, "jsonfile")

    @jsonfile.setter
    def jsonfile(self, value: pulumi.Input[str]):
        pulumi.set(self, "jsonfile", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        User defined description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def devicegroup(self) -> Optional[pulumi.Input[str]]:
        """
        BIG-IP password
        """
        return pulumi.get(self, "devicegroup")

    @devicegroup.setter
    def devicegroup(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "devicegroup", value)

    @property
    @pulumi.getter(name="executeAction")
    def execute_action(self) -> Optional[pulumi.Input[str]]:
        """
        Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        """
        return pulumi.get(self, "execute_action")

    @execute_action.setter
    def execute_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "execute_action", value)

    @property
    @pulumi.getter(name="inheritedDevicegroup")
    def inherited_devicegroup(self) -> Optional[pulumi.Input[str]]:
        """
        Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        """
        return pulumi.get(self, "inherited_devicegroup")

    @inherited_devicegroup.setter
    def inherited_devicegroup(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inherited_devicegroup", value)

    @property
    @pulumi.getter(name="inheritedTrafficGroup")
    def inherited_traffic_group(self) -> Optional[pulumi.Input[str]]:
        """
        Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        """
        return pulumi.get(self, "inherited_traffic_group")

    @inherited_traffic_group.setter
    def inherited_traffic_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inherited_traffic_group", value)

    @property
    @pulumi.getter
    def lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]]]:
        """
        string values
        """
        return pulumi.get(self, "lists")

    @lists.setter
    def lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]]]):
        pulumi.set(self, "lists", value)

    @property
    @pulumi.getter
    def metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]]]:
        """
        User defined generic data for the application service. It is a name and value pair.
        """
        return pulumi.get(self, "metadatas")

    @metadatas.setter
    def metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]]]):
        pulumi.set(self, "metadatas", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        Displays the administrative partition within which the application resides.
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="strictUpdates")
    def strict_updates(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        """
        return pulumi.get(self, "strict_updates")

    @strict_updates.setter
    def strict_updates(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "strict_updates", value)

    @property
    @pulumi.getter
    def tables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableArgs']]]]:
        return pulumi.get(self, "tables")

    @tables.setter
    def tables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableArgs']]]]):
        pulumi.set(self, "tables", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[str]]:
        """
        The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter(name="templateModified")
    def template_modified(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        """
        return pulumi.get(self, "template_modified")

    @template_modified.setter
    def template_modified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_modified", value)

    @property
    @pulumi.getter(name="templatePrerequisiteErrors")
    def template_prerequisite_errors(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates any missing prerequisites associated with the template that defines this application.
        """
        return pulumi.get(self, "template_prerequisite_errors")

    @template_prerequisite_errors.setter
    def template_prerequisite_errors(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_prerequisite_errors", value)

    @property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the traffic group that the application service is assigned to.
        """
        return pulumi.get(self, "traffic_group")

    @traffic_group.setter
    def traffic_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "traffic_group", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppVariableArgs']]]]:
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppVariableArgs']]]]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class _IAppState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 devicegroup: Optional[pulumi.Input[str]] = None,
                 execute_action: Optional[pulumi.Input[str]] = None,
                 inherited_devicegroup: Optional[pulumi.Input[str]] = None,
                 inherited_traffic_group: Optional[pulumi.Input[str]] = None,
                 jsonfile: Optional[pulumi.Input[str]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 strict_updates: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableArgs']]]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 template_modified: Optional[pulumi.Input[str]] = None,
                 template_prerequisite_errors: Optional[pulumi.Input[str]] = None,
                 traffic_group: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input['IAppVariableArgs']]]] = None):
        """
        Input properties used for looking up and filtering IApp resources.
        :param pulumi.Input[str] description: User defined description.
        :param pulumi.Input[str] devicegroup: BIG-IP password
        :param pulumi.Input[str] execute_action: Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        :param pulumi.Input[str] inherited_devicegroup: Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        :param pulumi.Input[str] inherited_traffic_group: Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        :param pulumi.Input[str] jsonfile: Refer to the Json file which will be deployed on F5 BIG-IP.
        :param pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]] lists: string values
        :param pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]] metadatas: User defined generic data for the application service. It is a name and value pair.
        :param pulumi.Input[str] name: Name of the iApp.
        :param pulumi.Input[str] partition: Displays the administrative partition within which the application resides.
        :param pulumi.Input[str] strict_updates: Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        :param pulumi.Input[str] template: The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        :param pulumi.Input[str] template_modified: Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        :param pulumi.Input[str] template_prerequisite_errors: Indicates any missing prerequisites associated with the template that defines this application.
        :param pulumi.Input[str] traffic_group: The name of the traffic group that the application service is assigned to.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if devicegroup is not None:
            pulumi.set(__self__, "devicegroup", devicegroup)
        if execute_action is not None:
            pulumi.set(__self__, "execute_action", execute_action)
        if inherited_devicegroup is not None:
            pulumi.set(__self__, "inherited_devicegroup", inherited_devicegroup)
        if inherited_traffic_group is not None:
            pulumi.set(__self__, "inherited_traffic_group", inherited_traffic_group)
        if jsonfile is not None:
            pulumi.set(__self__, "jsonfile", jsonfile)
        if lists is not None:
            pulumi.set(__self__, "lists", lists)
        if metadatas is not None:
            pulumi.set(__self__, "metadatas", metadatas)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if strict_updates is not None:
            pulumi.set(__self__, "strict_updates", strict_updates)
        if tables is not None:
            pulumi.set(__self__, "tables", tables)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if template_modified is not None:
            pulumi.set(__self__, "template_modified", template_modified)
        if template_prerequisite_errors is not None:
            pulumi.set(__self__, "template_prerequisite_errors", template_prerequisite_errors)
        if traffic_group is not None:
            pulumi.set(__self__, "traffic_group", traffic_group)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        User defined description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def devicegroup(self) -> Optional[pulumi.Input[str]]:
        """
        BIG-IP password
        """
        return pulumi.get(self, "devicegroup")

    @devicegroup.setter
    def devicegroup(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "devicegroup", value)

    @property
    @pulumi.getter(name="executeAction")
    def execute_action(self) -> Optional[pulumi.Input[str]]:
        """
        Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        """
        return pulumi.get(self, "execute_action")

    @execute_action.setter
    def execute_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "execute_action", value)

    @property
    @pulumi.getter(name="inheritedDevicegroup")
    def inherited_devicegroup(self) -> Optional[pulumi.Input[str]]:
        """
        Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        """
        return pulumi.get(self, "inherited_devicegroup")

    @inherited_devicegroup.setter
    def inherited_devicegroup(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inherited_devicegroup", value)

    @property
    @pulumi.getter(name="inheritedTrafficGroup")
    def inherited_traffic_group(self) -> Optional[pulumi.Input[str]]:
        """
        Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        """
        return pulumi.get(self, "inherited_traffic_group")

    @inherited_traffic_group.setter
    def inherited_traffic_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inherited_traffic_group", value)

    @property
    @pulumi.getter
    def jsonfile(self) -> Optional[pulumi.Input[str]]:
        """
        Refer to the Json file which will be deployed on F5 BIG-IP.
        """
        return pulumi.get(self, "jsonfile")

    @jsonfile.setter
    def jsonfile(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jsonfile", value)

    @property
    @pulumi.getter
    def lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]]]:
        """
        string values
        """
        return pulumi.get(self, "lists")

    @lists.setter
    def lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppListArgs']]]]):
        pulumi.set(self, "lists", value)

    @property
    @pulumi.getter
    def metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]]]:
        """
        User defined generic data for the application service. It is a name and value pair.
        """
        return pulumi.get(self, "metadatas")

    @metadatas.setter
    def metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppMetadataArgs']]]]):
        pulumi.set(self, "metadatas", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        Displays the administrative partition within which the application resides.
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="strictUpdates")
    def strict_updates(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        """
        return pulumi.get(self, "strict_updates")

    @strict_updates.setter
    def strict_updates(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "strict_updates", value)

    @property
    @pulumi.getter
    def tables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableArgs']]]]:
        return pulumi.get(self, "tables")

    @tables.setter
    def tables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableArgs']]]]):
        pulumi.set(self, "tables", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[str]]:
        """
        The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter(name="templateModified")
    def template_modified(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        """
        return pulumi.get(self, "template_modified")

    @template_modified.setter
    def template_modified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_modified", value)

    @property
    @pulumi.getter(name="templatePrerequisiteErrors")
    def template_prerequisite_errors(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates any missing prerequisites associated with the template that defines this application.
        """
        return pulumi.get(self, "template_prerequisite_errors")

    @template_prerequisite_errors.setter
    def template_prerequisite_errors(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_prerequisite_errors", value)

    @property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the traffic group that the application service is assigned to.
        """
        return pulumi.get(self, "traffic_group")

    @traffic_group.setter
    def traffic_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "traffic_group", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppVariableArgs']]]]:
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppVariableArgs']]]]):
        pulumi.set(self, "variables", value)


class IApp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 devicegroup: Optional[pulumi.Input[str]] = None,
                 execute_action: Optional[pulumi.Input[str]] = None,
                 inherited_devicegroup: Optional[pulumi.Input[str]] = None,
                 inherited_traffic_group: Optional[pulumi.Input[str]] = None,
                 jsonfile: Optional[pulumi.Input[str]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppListArgs', 'IAppListArgsDict']]]]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppMetadataArgs', 'IAppMetadataArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 strict_updates: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppTableArgs', 'IAppTableArgsDict']]]]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 template_modified: Optional[pulumi.Input[str]] = None,
                 template_prerequisite_errors: Optional[pulumi.Input[str]] = None,
                 traffic_group: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppVariableArgs', 'IAppVariableArgsDict']]]]] = None,
                 __props__=None):
        """
        `sys.IApp` resource helps you to deploy Application Services template that can be used to automate and orchestrate Layer 4-7 applications service deployments using F5 Network.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip
        import pulumi_std as std

        simplehttp = f5bigip.sys.IApp("simplehttp",
            name="simplehttp",
            jsonfile=std.file(input="simplehttp.json").result)
        ```

        ### Json File

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: User defined description.
        :param pulumi.Input[str] devicegroup: BIG-IP password
        :param pulumi.Input[str] execute_action: Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        :param pulumi.Input[str] inherited_devicegroup: Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        :param pulumi.Input[str] inherited_traffic_group: Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        :param pulumi.Input[str] jsonfile: Refer to the Json file which will be deployed on F5 BIG-IP.
        :param pulumi.Input[Sequence[pulumi.Input[Union['IAppListArgs', 'IAppListArgsDict']]]] lists: string values
        :param pulumi.Input[Sequence[pulumi.Input[Union['IAppMetadataArgs', 'IAppMetadataArgsDict']]]] metadatas: User defined generic data for the application service. It is a name and value pair.
        :param pulumi.Input[str] name: Name of the iApp.
        :param pulumi.Input[str] partition: Displays the administrative partition within which the application resides.
        :param pulumi.Input[str] strict_updates: Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        :param pulumi.Input[str] template: The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        :param pulumi.Input[str] template_modified: Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        :param pulumi.Input[str] template_prerequisite_errors: Indicates any missing prerequisites associated with the template that defines this application.
        :param pulumi.Input[str] traffic_group: The name of the traffic group that the application service is assigned to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IAppArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `sys.IApp` resource helps you to deploy Application Services template that can be used to automate and orchestrate Layer 4-7 applications service deployments using F5 Network.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip
        import pulumi_std as std

        simplehttp = f5bigip.sys.IApp("simplehttp",
            name="simplehttp",
            jsonfile=std.file(input="simplehttp.json").result)
        ```

        ### Json File

        :param str resource_name: The name of the resource.
        :param IAppArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IAppArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 devicegroup: Optional[pulumi.Input[str]] = None,
                 execute_action: Optional[pulumi.Input[str]] = None,
                 inherited_devicegroup: Optional[pulumi.Input[str]] = None,
                 inherited_traffic_group: Optional[pulumi.Input[str]] = None,
                 jsonfile: Optional[pulumi.Input[str]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppListArgs', 'IAppListArgsDict']]]]] = None,
                 metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppMetadataArgs', 'IAppMetadataArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 strict_updates: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppTableArgs', 'IAppTableArgsDict']]]]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 template_modified: Optional[pulumi.Input[str]] = None,
                 template_prerequisite_errors: Optional[pulumi.Input[str]] = None,
                 traffic_group: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppVariableArgs', 'IAppVariableArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IAppArgs.__new__(IAppArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["devicegroup"] = devicegroup
            __props__.__dict__["execute_action"] = execute_action
            __props__.__dict__["inherited_devicegroup"] = inherited_devicegroup
            __props__.__dict__["inherited_traffic_group"] = inherited_traffic_group
            if jsonfile is None and not opts.urn:
                raise TypeError("Missing required property 'jsonfile'")
            __props__.__dict__["jsonfile"] = jsonfile
            __props__.__dict__["lists"] = lists
            __props__.__dict__["metadatas"] = metadatas
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            __props__.__dict__["strict_updates"] = strict_updates
            __props__.__dict__["tables"] = tables
            __props__.__dict__["template"] = template
            __props__.__dict__["template_modified"] = template_modified
            __props__.__dict__["template_prerequisite_errors"] = template_prerequisite_errors
            __props__.__dict__["traffic_group"] = traffic_group
            __props__.__dict__["variables"] = variables
        super(IApp, __self__).__init__(
            'f5bigip:sys/iApp:IApp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            devicegroup: Optional[pulumi.Input[str]] = None,
            execute_action: Optional[pulumi.Input[str]] = None,
            inherited_devicegroup: Optional[pulumi.Input[str]] = None,
            inherited_traffic_group: Optional[pulumi.Input[str]] = None,
            jsonfile: Optional[pulumi.Input[str]] = None,
            lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppListArgs', 'IAppListArgsDict']]]]] = None,
            metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppMetadataArgs', 'IAppMetadataArgsDict']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            partition: Optional[pulumi.Input[str]] = None,
            strict_updates: Optional[pulumi.Input[str]] = None,
            tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppTableArgs', 'IAppTableArgsDict']]]]] = None,
            template: Optional[pulumi.Input[str]] = None,
            template_modified: Optional[pulumi.Input[str]] = None,
            template_prerequisite_errors: Optional[pulumi.Input[str]] = None,
            traffic_group: Optional[pulumi.Input[str]] = None,
            variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IAppVariableArgs', 'IAppVariableArgsDict']]]]] = None) -> 'IApp':
        """
        Get an existing IApp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: User defined description.
        :param pulumi.Input[str] devicegroup: BIG-IP password
        :param pulumi.Input[str] execute_action: Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        :param pulumi.Input[str] inherited_devicegroup: Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        :param pulumi.Input[str] inherited_traffic_group: Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        :param pulumi.Input[str] jsonfile: Refer to the Json file which will be deployed on F5 BIG-IP.
        :param pulumi.Input[Sequence[pulumi.Input[Union['IAppListArgs', 'IAppListArgsDict']]]] lists: string values
        :param pulumi.Input[Sequence[pulumi.Input[Union['IAppMetadataArgs', 'IAppMetadataArgsDict']]]] metadatas: User defined generic data for the application service. It is a name and value pair.
        :param pulumi.Input[str] name: Name of the iApp.
        :param pulumi.Input[str] partition: Displays the administrative partition within which the application resides.
        :param pulumi.Input[str] strict_updates: Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        :param pulumi.Input[str] template: The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        :param pulumi.Input[str] template_modified: Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        :param pulumi.Input[str] template_prerequisite_errors: Indicates any missing prerequisites associated with the template that defines this application.
        :param pulumi.Input[str] traffic_group: The name of the traffic group that the application service is assigned to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IAppState.__new__(_IAppState)

        __props__.__dict__["description"] = description
        __props__.__dict__["devicegroup"] = devicegroup
        __props__.__dict__["execute_action"] = execute_action
        __props__.__dict__["inherited_devicegroup"] = inherited_devicegroup
        __props__.__dict__["inherited_traffic_group"] = inherited_traffic_group
        __props__.__dict__["jsonfile"] = jsonfile
        __props__.__dict__["lists"] = lists
        __props__.__dict__["metadatas"] = metadatas
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["strict_updates"] = strict_updates
        __props__.__dict__["tables"] = tables
        __props__.__dict__["template"] = template
        __props__.__dict__["template_modified"] = template_modified
        __props__.__dict__["template_prerequisite_errors"] = template_prerequisite_errors
        __props__.__dict__["traffic_group"] = traffic_group
        __props__.__dict__["variables"] = variables
        return IApp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        User defined description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def devicegroup(self) -> pulumi.Output[str]:
        """
        BIG-IP password
        """
        return pulumi.get(self, "devicegroup")

    @property
    @pulumi.getter(name="executeAction")
    def execute_action(self) -> pulumi.Output[str]:
        """
        Run the specified template action associated with the application, this option can be specified in `json` with `executeAction`, value specified with `execute_action` attribute take precedence over `json` value
        """
        return pulumi.get(self, "execute_action")

    @property
    @pulumi.getter(name="inheritedDevicegroup")
    def inherited_devicegroup(self) -> pulumi.Output[Optional[str]]:
        """
        Read-only. Shows whether the application folder will automatically remain with the same device-group as its parent folder. Use 'device-group default' or 'device-group non-default' to set this.
        """
        return pulumi.get(self, "inherited_devicegroup")

    @property
    @pulumi.getter(name="inheritedTrafficGroup")
    def inherited_traffic_group(self) -> pulumi.Output[Optional[str]]:
        """
        Read-only. Shows whether the application folder will automatically remain with the same traffic-group as its parent folder. Use 'traffic-group default' or 'traffic-group non-default' to set this.
        """
        return pulumi.get(self, "inherited_traffic_group")

    @property
    @pulumi.getter
    def jsonfile(self) -> pulumi.Output[str]:
        """
        Refer to the Json file which will be deployed on F5 BIG-IP.
        """
        return pulumi.get(self, "jsonfile")

    @property
    @pulumi.getter
    def lists(self) -> pulumi.Output[Optional[Sequence['outputs.IAppList']]]:
        """
        string values
        """
        return pulumi.get(self, "lists")

    @property
    @pulumi.getter
    def metadatas(self) -> pulumi.Output[Optional[Sequence['outputs.IAppMetadata']]]:
        """
        User defined generic data for the application service. It is a name and value pair.
        """
        return pulumi.get(self, "metadatas")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> pulumi.Output[Optional[str]]:
        """
        Displays the administrative partition within which the application resides.
        """
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="strictUpdates")
    def strict_updates(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies whether configuration objects contained in the application may be directly modified, outside the context of the system's application management interfaces.
        """
        return pulumi.get(self, "strict_updates")

    @property
    @pulumi.getter
    def tables(self) -> pulumi.Output[Optional[Sequence['outputs.IAppTable']]]:
        return pulumi.get(self, "tables")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[Optional[str]]:
        """
        The template defines the configuration for the application. This may be changed after the application has been created to move the application to a new template.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter(name="templateModified")
    def template_modified(self) -> pulumi.Output[Optional[str]]:
        """
        Indicates that the application template used to deploy the application has been modified. The application should be updated to make use of the latest changes.
        """
        return pulumi.get(self, "template_modified")

    @property
    @pulumi.getter(name="templatePrerequisiteErrors")
    def template_prerequisite_errors(self) -> pulumi.Output[Optional[str]]:
        """
        Indicates any missing prerequisites associated with the template that defines this application.
        """
        return pulumi.get(self, "template_prerequisite_errors")

    @property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the traffic group that the application service is assigned to.
        """
        return pulumi.get(self, "traffic_group")

    @property
    @pulumi.getter
    def variables(self) -> pulumi.Output[Optional[Sequence['outputs.IAppVariable']]]:
        return pulumi.get(self, "variables")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VlanArgs', 'Vlan']

@pulumi.input_type
class VlanArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 cmp_hash: Optional[pulumi.Input[str]] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 tag: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Vlan resource.
        :param pulumi.Input[str] name: Name of the vlan
        :param pulumi.Input[str] cmp_hash: Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        :param pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]] interfaces: Specifies which interfaces you want this VLAN to use for traffic management.
        :param pulumi.Input[int] mtu: Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        :param pulumi.Input[int] tag: Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        pulumi.set(__self__, "name", name)
        if cmp_hash is not None:
            pulumi.set(__self__, "cmp_hash", cmp_hash)
        if interfaces is not None:
            pulumi.set(__self__, "interfaces", interfaces)
        if mtu is not None:
            pulumi.set(__self__, "mtu", mtu)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the vlan
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="cmpHash")
    def cmp_hash(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        """
        return pulumi.get(self, "cmp_hash")

    @cmp_hash.setter
    def cmp_hash(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cmp_hash", value)

    @property
    @pulumi.getter
    def interfaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]]]:
        """
        Specifies which interfaces you want this VLAN to use for traffic management.
        """
        return pulumi.get(self, "interfaces")

    @interfaces.setter
    def interfaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]]]):
        pulumi.set(self, "interfaces", value)

    @property
    @pulumi.getter
    def mtu(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        """
        return pulumi.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mtu", value)

    @property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tag", value)


@pulumi.input_type
class _VlanState:
    def __init__(__self__, *,
                 cmp_hash: Optional[pulumi.Input[str]] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tag: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Vlan resources.
        :param pulumi.Input[str] cmp_hash: Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        :param pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]] interfaces: Specifies which interfaces you want this VLAN to use for traffic management.
        :param pulumi.Input[int] mtu: Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        :param pulumi.Input[str] name: Name of the vlan
        :param pulumi.Input[int] tag: Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        if cmp_hash is not None:
            pulumi.set(__self__, "cmp_hash", cmp_hash)
        if interfaces is not None:
            pulumi.set(__self__, "interfaces", interfaces)
        if mtu is not None:
            pulumi.set(__self__, "mtu", mtu)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)

    @property
    @pulumi.getter(name="cmpHash")
    def cmp_hash(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        """
        return pulumi.get(self, "cmp_hash")

    @cmp_hash.setter
    def cmp_hash(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cmp_hash", value)

    @property
    @pulumi.getter
    def interfaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]]]:
        """
        Specifies which interfaces you want this VLAN to use for traffic management.
        """
        return pulumi.get(self, "interfaces")

    @interfaces.setter
    def interfaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VlanInterfaceArgs']]]]):
        pulumi.set(self, "interfaces", value)

    @property
    @pulumi.getter
    def mtu(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        """
        return pulumi.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mtu", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the vlan
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tag", value)


class Vlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cmp_hash: Optional[pulumi.Input[str]] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VlanInterfaceArgs', 'VlanInterfaceArgsDict']]]]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tag: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        `net.Vlan` Manages a vlan configuration

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vlan1 = f5bigip.net.Vlan("vlan1",
            name="/Common/Internal",
            tag=101,
            interfaces=[{
                "vlanport": "1.2",
                "tagged": False,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cmp_hash: Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        :param pulumi.Input[Sequence[pulumi.Input[Union['VlanInterfaceArgs', 'VlanInterfaceArgsDict']]]] interfaces: Specifies which interfaces you want this VLAN to use for traffic management.
        :param pulumi.Input[int] mtu: Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        :param pulumi.Input[str] name: Name of the vlan
        :param pulumi.Input[int] tag: Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `net.Vlan` Manages a vlan configuration

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vlan1 = f5bigip.net.Vlan("vlan1",
            name="/Common/Internal",
            tag=101,
            interfaces=[{
                "vlanport": "1.2",
                "tagged": False,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param VlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cmp_hash: Optional[pulumi.Input[str]] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VlanInterfaceArgs', 'VlanInterfaceArgsDict']]]]] = None,
                 mtu: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tag: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VlanArgs.__new__(VlanArgs)

            __props__.__dict__["cmp_hash"] = cmp_hash
            __props__.__dict__["interfaces"] = interfaces
            __props__.__dict__["mtu"] = mtu
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["tag"] = tag
        super(Vlan, __self__).__init__(
            'f5bigip:net/vlan:Vlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cmp_hash: Optional[pulumi.Input[str]] = None,
            interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VlanInterfaceArgs', 'VlanInterfaceArgsDict']]]]] = None,
            mtu: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            tag: Optional[pulumi.Input[int]] = None) -> 'Vlan':
        """
        Get an existing Vlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cmp_hash: Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        :param pulumi.Input[Sequence[pulumi.Input[Union['VlanInterfaceArgs', 'VlanInterfaceArgsDict']]]] interfaces: Specifies which interfaces you want this VLAN to use for traffic management.
        :param pulumi.Input[int] mtu: Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        :param pulumi.Input[str] name: Name of the vlan
        :param pulumi.Input[int] tag: Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VlanState.__new__(_VlanState)

        __props__.__dict__["cmp_hash"] = cmp_hash
        __props__.__dict__["interfaces"] = interfaces
        __props__.__dict__["mtu"] = mtu
        __props__.__dict__["name"] = name
        __props__.__dict__["tag"] = tag
        return Vlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cmpHash")
    def cmp_hash(self) -> pulumi.Output[str]:
        """
        Specifies how the traffic on the VLAN will be disaggregated. The value selected determines the traffic disaggregation method. possible options: [`default`, `src-ip`, `dst-ip`]
        """
        return pulumi.get(self, "cmp_hash")

    @property
    @pulumi.getter
    def interfaces(self) -> pulumi.Output[Optional[Sequence['outputs.VlanInterface']]]:
        """
        Specifies which interfaces you want this VLAN to use for traffic management.
        """
        return pulumi.get(self, "interfaces")

    @property
    @pulumi.getter
    def mtu(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the maximum transmission unit (MTU) for traffic on this VLAN. The default value is `1500`.
        """
        return pulumi.get(self, "mtu")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the vlan
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def tag(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies a number that the system adds into the header of any frame passing through the VLAN.
        """
        return pulumi.get(self, "tag")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GuestArgs', 'Guest']

@pulumi.input_type
class GuestArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 allowed_slots: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 cores_per_slot: Optional[pulumi.Input[int]] = None,
                 delete_virtual_disk: Optional[pulumi.Input[bool]] = None,
                 initial_hotfix: Optional[pulumi.Input[str]] = None,
                 initial_image: Optional[pulumi.Input[str]] = None,
                 mgmt_address: Optional[pulumi.Input[str]] = None,
                 mgmt_network: Optional[pulumi.Input[str]] = None,
                 mgmt_route: Optional[pulumi.Input[str]] = None,
                 min_number_of_slots: Optional[pulumi.Input[int]] = None,
                 number_of_slots: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 vlans: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Guest resource.
        :param pulumi.Input[str] name: Name of the vCMP guest
        :param pulumi.Input[Sequence[pulumi.Input[int]]] allowed_slots: Contains those slots to which the guest is allowed to be assigned.
        :param pulumi.Input[int] cores_per_slot: Specifies the number of cores the system allocates to the guest.
        :param pulumi.Input[bool] delete_virtual_disk: Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        :param pulumi.Input[str] initial_hotfix: Specifies the hotfix ISO image file which is applied on top of the base image.
        :param pulumi.Input[str] initial_image: Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        :param pulumi.Input[str] mgmt_address: Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        :param pulumi.Input[str] mgmt_network: Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        :param pulumi.Input[str] mgmt_route: Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        :param pulumi.Input[int] min_number_of_slots: Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        :param pulumi.Input[int] number_of_slots: Specifies the number of slots for the system to use when creating the guest.
        :param pulumi.Input[str] state: Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vlans: Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        pulumi.set(__self__, "name", name)
        if allowed_slots is not None:
            pulumi.set(__self__, "allowed_slots", allowed_slots)
        if cores_per_slot is not None:
            pulumi.set(__self__, "cores_per_slot", cores_per_slot)
        if delete_virtual_disk is not None:
            pulumi.set(__self__, "delete_virtual_disk", delete_virtual_disk)
        if initial_hotfix is not None:
            pulumi.set(__self__, "initial_hotfix", initial_hotfix)
        if initial_image is not None:
            pulumi.set(__self__, "initial_image", initial_image)
        if mgmt_address is not None:
            pulumi.set(__self__, "mgmt_address", mgmt_address)
        if mgmt_network is not None:
            pulumi.set(__self__, "mgmt_network", mgmt_network)
        if mgmt_route is not None:
            pulumi.set(__self__, "mgmt_route", mgmt_route)
        if min_number_of_slots is not None:
            pulumi.set(__self__, "min_number_of_slots", min_number_of_slots)
        if number_of_slots is not None:
            pulumi.set(__self__, "number_of_slots", number_of_slots)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if vlans is not None:
            pulumi.set(__self__, "vlans", vlans)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the vCMP guest
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="allowedSlots")
    def allowed_slots(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        Contains those slots to which the guest is allowed to be assigned.
        """
        return pulumi.get(self, "allowed_slots")

    @allowed_slots.setter
    def allowed_slots(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "allowed_slots", value)

    @property
    @pulumi.getter(name="coresPerSlot")
    def cores_per_slot(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of cores the system allocates to the guest.
        """
        return pulumi.get(self, "cores_per_slot")

    @cores_per_slot.setter
    def cores_per_slot(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cores_per_slot", value)

    @property
    @pulumi.getter(name="deleteVirtualDisk")
    def delete_virtual_disk(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        """
        return pulumi.get(self, "delete_virtual_disk")

    @delete_virtual_disk.setter
    def delete_virtual_disk(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_virtual_disk", value)

    @property
    @pulumi.getter(name="initialHotfix")
    def initial_hotfix(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the hotfix ISO image file which is applied on top of the base image.
        """
        return pulumi.get(self, "initial_hotfix")

    @initial_hotfix.setter
    def initial_hotfix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "initial_hotfix", value)

    @property
    @pulumi.getter(name="initialImage")
    def initial_image(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        """
        return pulumi.get(self, "initial_image")

    @initial_image.setter
    def initial_image(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "initial_image", value)

    @property
    @pulumi.getter(name="mgmtAddress")
    def mgmt_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        """
        return pulumi.get(self, "mgmt_address")

    @mgmt_address.setter
    def mgmt_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mgmt_address", value)

    @property
    @pulumi.getter(name="mgmtNetwork")
    def mgmt_network(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        """
        return pulumi.get(self, "mgmt_network")

    @mgmt_network.setter
    def mgmt_network(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mgmt_network", value)

    @property
    @pulumi.getter(name="mgmtRoute")
    def mgmt_route(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        """
        return pulumi.get(self, "mgmt_route")

    @mgmt_route.setter
    def mgmt_route(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mgmt_route", value)

    @property
    @pulumi.getter(name="minNumberOfSlots")
    def min_number_of_slots(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        """
        return pulumi.get(self, "min_number_of_slots")

    @min_number_of_slots.setter
    def min_number_of_slots(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_number_of_slots", value)

    @property
    @pulumi.getter(name="numberOfSlots")
    def number_of_slots(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of slots for the system to use when creating the guest.
        """
        return pulumi.get(self, "number_of_slots")

    @number_of_slots.setter
    def number_of_slots(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "number_of_slots", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def vlans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        return pulumi.get(self, "vlans")

    @vlans.setter
    def vlans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "vlans", value)


@pulumi.input_type
class _GuestState:
    def __init__(__self__, *,
                 allowed_slots: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 cores_per_slot: Optional[pulumi.Input[int]] = None,
                 delete_virtual_disk: Optional[pulumi.Input[bool]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 initial_hotfix: Optional[pulumi.Input[str]] = None,
                 initial_image: Optional[pulumi.Input[str]] = None,
                 mgmt_address: Optional[pulumi.Input[str]] = None,
                 mgmt_network: Optional[pulumi.Input[str]] = None,
                 mgmt_route: Optional[pulumi.Input[str]] = None,
                 min_number_of_slots: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 number_of_slots: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 virtual_disk: Optional[pulumi.Input[str]] = None,
                 vlans: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Guest resources.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] allowed_slots: Contains those slots to which the guest is allowed to be assigned.
        :param pulumi.Input[int] cores_per_slot: Specifies the number of cores the system allocates to the guest.
        :param pulumi.Input[bool] delete_virtual_disk: Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        :param pulumi.Input[str] full_path: Resource name including prepended partition path.
        :param pulumi.Input[str] initial_hotfix: Specifies the hotfix ISO image file which is applied on top of the base image.
        :param pulumi.Input[str] initial_image: Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        :param pulumi.Input[str] mgmt_address: Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        :param pulumi.Input[str] mgmt_network: Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        :param pulumi.Input[str] mgmt_route: Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        :param pulumi.Input[int] min_number_of_slots: Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        :param pulumi.Input[str] name: Name of the vCMP guest
        :param pulumi.Input[int] number_of_slots: Specifies the number of slots for the system to use when creating the guest.
        :param pulumi.Input[str] state: Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        :param pulumi.Input[str] virtual_disk: Virtual disk associated with vCMP guest.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vlans: Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        if allowed_slots is not None:
            pulumi.set(__self__, "allowed_slots", allowed_slots)
        if cores_per_slot is not None:
            pulumi.set(__self__, "cores_per_slot", cores_per_slot)
        if delete_virtual_disk is not None:
            pulumi.set(__self__, "delete_virtual_disk", delete_virtual_disk)
        if full_path is not None:
            pulumi.set(__self__, "full_path", full_path)
        if initial_hotfix is not None:
            pulumi.set(__self__, "initial_hotfix", initial_hotfix)
        if initial_image is not None:
            pulumi.set(__self__, "initial_image", initial_image)
        if mgmt_address is not None:
            pulumi.set(__self__, "mgmt_address", mgmt_address)
        if mgmt_network is not None:
            pulumi.set(__self__, "mgmt_network", mgmt_network)
        if mgmt_route is not None:
            pulumi.set(__self__, "mgmt_route", mgmt_route)
        if min_number_of_slots is not None:
            pulumi.set(__self__, "min_number_of_slots", min_number_of_slots)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if number_of_slots is not None:
            pulumi.set(__self__, "number_of_slots", number_of_slots)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if virtual_disk is not None:
            pulumi.set(__self__, "virtual_disk", virtual_disk)
        if vlans is not None:
            pulumi.set(__self__, "vlans", vlans)

    @property
    @pulumi.getter(name="allowedSlots")
    def allowed_slots(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        Contains those slots to which the guest is allowed to be assigned.
        """
        return pulumi.get(self, "allowed_slots")

    @allowed_slots.setter
    def allowed_slots(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "allowed_slots", value)

    @property
    @pulumi.getter(name="coresPerSlot")
    def cores_per_slot(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of cores the system allocates to the guest.
        """
        return pulumi.get(self, "cores_per_slot")

    @cores_per_slot.setter
    def cores_per_slot(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cores_per_slot", value)

    @property
    @pulumi.getter(name="deleteVirtualDisk")
    def delete_virtual_disk(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        """
        return pulumi.get(self, "delete_virtual_disk")

    @delete_virtual_disk.setter
    def delete_virtual_disk(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_virtual_disk", value)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Resource name including prepended partition path.
        """
        return pulumi.get(self, "full_path")

    @full_path.setter
    def full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_path", value)

    @property
    @pulumi.getter(name="initialHotfix")
    def initial_hotfix(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the hotfix ISO image file which is applied on top of the base image.
        """
        return pulumi.get(self, "initial_hotfix")

    @initial_hotfix.setter
    def initial_hotfix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "initial_hotfix", value)

    @property
    @pulumi.getter(name="initialImage")
    def initial_image(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        """
        return pulumi.get(self, "initial_image")

    @initial_image.setter
    def initial_image(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "initial_image", value)

    @property
    @pulumi.getter(name="mgmtAddress")
    def mgmt_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        """
        return pulumi.get(self, "mgmt_address")

    @mgmt_address.setter
    def mgmt_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mgmt_address", value)

    @property
    @pulumi.getter(name="mgmtNetwork")
    def mgmt_network(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        """
        return pulumi.get(self, "mgmt_network")

    @mgmt_network.setter
    def mgmt_network(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mgmt_network", value)

    @property
    @pulumi.getter(name="mgmtRoute")
    def mgmt_route(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        """
        return pulumi.get(self, "mgmt_route")

    @mgmt_route.setter
    def mgmt_route(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mgmt_route", value)

    @property
    @pulumi.getter(name="minNumberOfSlots")
    def min_number_of_slots(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        """
        return pulumi.get(self, "min_number_of_slots")

    @min_number_of_slots.setter
    def min_number_of_slots(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_number_of_slots", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the vCMP guest
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="numberOfSlots")
    def number_of_slots(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of slots for the system to use when creating the guest.
        """
        return pulumi.get(self, "number_of_slots")

    @number_of_slots.setter
    def number_of_slots(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "number_of_slots", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="virtualDisk")
    def virtual_disk(self) -> Optional[pulumi.Input[str]]:
        """
        Virtual disk associated with vCMP guest.
        """
        return pulumi.get(self, "virtual_disk")

    @virtual_disk.setter
    def virtual_disk(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_disk", value)

    @property
    @pulumi.getter
    def vlans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        return pulumi.get(self, "vlans")

    @vlans.setter
    def vlans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "vlans", value)


class Guest(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_slots: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 cores_per_slot: Optional[pulumi.Input[int]] = None,
                 delete_virtual_disk: Optional[pulumi.Input[bool]] = None,
                 initial_hotfix: Optional[pulumi.Input[str]] = None,
                 initial_image: Optional[pulumi.Input[str]] = None,
                 mgmt_address: Optional[pulumi.Input[str]] = None,
                 mgmt_network: Optional[pulumi.Input[str]] = None,
                 mgmt_route: Optional[pulumi.Input[str]] = None,
                 min_number_of_slots: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 number_of_slots: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 vlans: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        `vcmp.Guest` Manages a vCMP guest configuration

        Resource does not wait for vCMP guest to reach the desired state, it only ensures that a desired configuration is set on the target device.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vcmp_test = f5bigip.vcmp.Guest("vcmp-test",
            name="tf_guest",
            initial_image="12.1.2.iso",
            mgmt_network="bridged",
            mgmt_address="10.1.1.1/24",
            mgmt_route="none",
            state="provisioned",
            cores_per_slot=2,
            number_of_slots=1,
            min_number_of_slots=1)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] allowed_slots: Contains those slots to which the guest is allowed to be assigned.
        :param pulumi.Input[int] cores_per_slot: Specifies the number of cores the system allocates to the guest.
        :param pulumi.Input[bool] delete_virtual_disk: Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        :param pulumi.Input[str] initial_hotfix: Specifies the hotfix ISO image file which is applied on top of the base image.
        :param pulumi.Input[str] initial_image: Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        :param pulumi.Input[str] mgmt_address: Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        :param pulumi.Input[str] mgmt_network: Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        :param pulumi.Input[str] mgmt_route: Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        :param pulumi.Input[int] min_number_of_slots: Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        :param pulumi.Input[str] name: Name of the vCMP guest
        :param pulumi.Input[int] number_of_slots: Specifies the number of slots for the system to use when creating the guest.
        :param pulumi.Input[str] state: Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vlans: Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GuestArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `vcmp.Guest` Manages a vCMP guest configuration

        Resource does not wait for vCMP guest to reach the desired state, it only ensures that a desired configuration is set on the target device.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vcmp_test = f5bigip.vcmp.Guest("vcmp-test",
            name="tf_guest",
            initial_image="12.1.2.iso",
            mgmt_network="bridged",
            mgmt_address="10.1.1.1/24",
            mgmt_route="none",
            state="provisioned",
            cores_per_slot=2,
            number_of_slots=1,
            min_number_of_slots=1)
        ```

        :param str resource_name: The name of the resource.
        :param GuestArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GuestArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_slots: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 cores_per_slot: Optional[pulumi.Input[int]] = None,
                 delete_virtual_disk: Optional[pulumi.Input[bool]] = None,
                 initial_hotfix: Optional[pulumi.Input[str]] = None,
                 initial_image: Optional[pulumi.Input[str]] = None,
                 mgmt_address: Optional[pulumi.Input[str]] = None,
                 mgmt_network: Optional[pulumi.Input[str]] = None,
                 mgmt_route: Optional[pulumi.Input[str]] = None,
                 min_number_of_slots: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 number_of_slots: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 vlans: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GuestArgs.__new__(GuestArgs)

            __props__.__dict__["allowed_slots"] = allowed_slots
            __props__.__dict__["cores_per_slot"] = cores_per_slot
            __props__.__dict__["delete_virtual_disk"] = delete_virtual_disk
            __props__.__dict__["initial_hotfix"] = initial_hotfix
            __props__.__dict__["initial_image"] = initial_image
            __props__.__dict__["mgmt_address"] = mgmt_address
            __props__.__dict__["mgmt_network"] = mgmt_network
            __props__.__dict__["mgmt_route"] = mgmt_route
            __props__.__dict__["min_number_of_slots"] = min_number_of_slots
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["number_of_slots"] = number_of_slots
            __props__.__dict__["state"] = state
            __props__.__dict__["vlans"] = vlans
            __props__.__dict__["full_path"] = None
            __props__.__dict__["virtual_disk"] = None
        super(Guest, __self__).__init__(
            'f5bigip:vcmp/guest:Guest',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_slots: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            cores_per_slot: Optional[pulumi.Input[int]] = None,
            delete_virtual_disk: Optional[pulumi.Input[bool]] = None,
            full_path: Optional[pulumi.Input[str]] = None,
            initial_hotfix: Optional[pulumi.Input[str]] = None,
            initial_image: Optional[pulumi.Input[str]] = None,
            mgmt_address: Optional[pulumi.Input[str]] = None,
            mgmt_network: Optional[pulumi.Input[str]] = None,
            mgmt_route: Optional[pulumi.Input[str]] = None,
            min_number_of_slots: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            number_of_slots: Optional[pulumi.Input[int]] = None,
            state: Optional[pulumi.Input[str]] = None,
            virtual_disk: Optional[pulumi.Input[str]] = None,
            vlans: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Guest':
        """
        Get an existing Guest resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] allowed_slots: Contains those slots to which the guest is allowed to be assigned.
        :param pulumi.Input[int] cores_per_slot: Specifies the number of cores the system allocates to the guest.
        :param pulumi.Input[bool] delete_virtual_disk: Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        :param pulumi.Input[str] full_path: Resource name including prepended partition path.
        :param pulumi.Input[str] initial_hotfix: Specifies the hotfix ISO image file which is applied on top of the base image.
        :param pulumi.Input[str] initial_image: Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        :param pulumi.Input[str] mgmt_address: Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        :param pulumi.Input[str] mgmt_network: Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        :param pulumi.Input[str] mgmt_route: Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        :param pulumi.Input[int] min_number_of_slots: Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        :param pulumi.Input[str] name: Name of the vCMP guest
        :param pulumi.Input[int] number_of_slots: Specifies the number of slots for the system to use when creating the guest.
        :param pulumi.Input[str] state: Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        :param pulumi.Input[str] virtual_disk: Virtual disk associated with vCMP guest.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vlans: Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GuestState.__new__(_GuestState)

        __props__.__dict__["allowed_slots"] = allowed_slots
        __props__.__dict__["cores_per_slot"] = cores_per_slot
        __props__.__dict__["delete_virtual_disk"] = delete_virtual_disk
        __props__.__dict__["full_path"] = full_path
        __props__.__dict__["initial_hotfix"] = initial_hotfix
        __props__.__dict__["initial_image"] = initial_image
        __props__.__dict__["mgmt_address"] = mgmt_address
        __props__.__dict__["mgmt_network"] = mgmt_network
        __props__.__dict__["mgmt_route"] = mgmt_route
        __props__.__dict__["min_number_of_slots"] = min_number_of_slots
        __props__.__dict__["name"] = name
        __props__.__dict__["number_of_slots"] = number_of_slots
        __props__.__dict__["state"] = state
        __props__.__dict__["virtual_disk"] = virtual_disk
        __props__.__dict__["vlans"] = vlans
        return Guest(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedSlots")
    def allowed_slots(self) -> pulumi.Output[Sequence[int]]:
        """
        Contains those slots to which the guest is allowed to be assigned.
        """
        return pulumi.get(self, "allowed_slots")

    @property
    @pulumi.getter(name="coresPerSlot")
    def cores_per_slot(self) -> pulumi.Output[int]:
        """
        Specifies the number of cores the system allocates to the guest.
        """
        return pulumi.get(self, "cores_per_slot")

    @property
    @pulumi.getter(name="deleteVirtualDisk")
    def delete_virtual_disk(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates if virtual disk associated with vCMP guest should be removed during remove operation.  The default is `true`
        """
        return pulumi.get(self, "delete_virtual_disk")

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> pulumi.Output[str]:
        """
        Resource name including prepended partition path.
        """
        return pulumi.get(self, "full_path")

    @property
    @pulumi.getter(name="initialHotfix")
    def initial_hotfix(self) -> pulumi.Output[str]:
        """
        Specifies the hotfix ISO image file which is applied on top of the base image.
        """
        return pulumi.get(self, "initial_hotfix")

    @property
    @pulumi.getter(name="initialImage")
    def initial_image(self) -> pulumi.Output[str]:
        """
        Specifies the base software release ISO image file for installing the TMOS hypervisor instance.
        """
        return pulumi.get(self, "initial_image")

    @property
    @pulumi.getter(name="mgmtAddress")
    def mgmt_address(self) -> pulumi.Output[str]:
        """
        Specifies the IP address and subnet or subnet mask you use to access the guest when you want to manage a module running within the guest.
        """
        return pulumi.get(self, "mgmt_address")

    @property
    @pulumi.getter(name="mgmtNetwork")
    def mgmt_network(self) -> pulumi.Output[str]:
        """
        Specifies the method by which the management address is used in the vCMP guest. options : [`bridged`,`isolated`,`host-only`].
        """
        return pulumi.get(self, "mgmt_network")

    @property
    @pulumi.getter(name="mgmtRoute")
    def mgmt_route(self) -> pulumi.Output[str]:
        """
        Specifies the gateway address for the `mgmt_address`. Can be set to `none` to remove the value from the configuration.
        """
        return pulumi.get(self, "mgmt_route")

    @property
    @pulumi.getter(name="minNumberOfSlots")
    def min_number_of_slots(self) -> pulumi.Output[int]:
        """
        Specifies the minimum number of slots the guest must be assigned to in order to deploy.
        """
        return pulumi.get(self, "min_number_of_slots")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the vCMP guest
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="numberOfSlots")
    def number_of_slots(self) -> pulumi.Output[int]:
        """
        Specifies the number of slots for the system to use when creating the guest.
        """
        return pulumi.get(self, "number_of_slots")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        Specifies the state of the vCMP guest on the system. options : [`configured`,`provisioned`,`deployed`].
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="virtualDisk")
    def virtual_disk(self) -> pulumi.Output[str]:
        """
        Virtual disk associated with vCMP guest.
        """
        return pulumi.get(self, "virtual_disk")

    @property
    @pulumi.getter
    def vlans(self) -> pulumi.Output[Sequence[str]]:
        """
        Specifies the list of VLANs the vCMP guest uses to communicate with other guests, the host, and with the external network. The naming format must be the combination of the partition + name. For example /Common/my-vlan
        """
        return pulumi.get(self, "vlans")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProfileHttpCompressArgs', 'ProfileHttpCompress']

@pulumi.input_type
class ProfileHttpCompressArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 compression_buffersize: Optional[pulumi.Input[int]] = None,
                 content_type_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 content_type_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cpu_saver: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 gzip_compression_level: Optional[pulumi.Input[int]] = None,
                 gzip_memory_level: Optional[pulumi.Input[int]] = None,
                 gzip_window_size: Optional[pulumi.Input[int]] = None,
                 keep_accept_encoding: Optional[pulumi.Input[str]] = None,
                 uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vary_header: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProfileHttpCompress resource.
        :param pulumi.Input[str] name: Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        :param pulumi.Input[int] compression_buffersize: Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_excludes: Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_includes: Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[str] cpu_saver: Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[int] gzip_compression_level: Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        :param pulumi.Input[int] gzip_memory_level: Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        :param pulumi.Input[int] gzip_window_size: Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        :param pulumi.Input[str] keep_accept_encoding: Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_excludes: Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_includes: Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        :param pulumi.Input[str] vary_header: Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        pulumi.set(__self__, "name", name)
        if compression_buffersize is not None:
            pulumi.set(__self__, "compression_buffersize", compression_buffersize)
        if content_type_excludes is not None:
            pulumi.set(__self__, "content_type_excludes", content_type_excludes)
        if content_type_includes is not None:
            pulumi.set(__self__, "content_type_includes", content_type_includes)
        if cpu_saver is not None:
            pulumi.set(__self__, "cpu_saver", cpu_saver)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if gzip_compression_level is not None:
            pulumi.set(__self__, "gzip_compression_level", gzip_compression_level)
        if gzip_memory_level is not None:
            pulumi.set(__self__, "gzip_memory_level", gzip_memory_level)
        if gzip_window_size is not None:
            pulumi.set(__self__, "gzip_window_size", gzip_window_size)
        if keep_accept_encoding is not None:
            pulumi.set(__self__, "keep_accept_encoding", keep_accept_encoding)
        if uri_excludes is not None:
            pulumi.set(__self__, "uri_excludes", uri_excludes)
        if uri_includes is not None:
            pulumi.set(__self__, "uri_includes", uri_includes)
        if vary_header is not None:
            pulumi.set(__self__, "vary_header", vary_header)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="compressionBuffersize")
    def compression_buffersize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        """
        return pulumi.get(self, "compression_buffersize")

    @compression_buffersize.setter
    def compression_buffersize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "compression_buffersize", value)

    @property
    @pulumi.getter(name="contentTypeExcludes")
    def content_type_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        """
        return pulumi.get(self, "content_type_excludes")

    @content_type_excludes.setter
    def content_type_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "content_type_excludes", value)

    @property
    @pulumi.getter(name="contentTypeIncludes")
    def content_type_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        """
        return pulumi.get(self, "content_type_includes")

    @content_type_includes.setter
    def content_type_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "content_type_includes", value)

    @property
    @pulumi.getter(name="cpuSaver")
    def cpu_saver(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        """
        return pulumi.get(self, "cpu_saver")

    @cpu_saver.setter
    def cpu_saver(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cpu_saver", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="gzipCompressionLevel")
    def gzip_compression_level(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        """
        return pulumi.get(self, "gzip_compression_level")

    @gzip_compression_level.setter
    def gzip_compression_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gzip_compression_level", value)

    @property
    @pulumi.getter(name="gzipMemoryLevel")
    def gzip_memory_level(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        """
        return pulumi.get(self, "gzip_memory_level")

    @gzip_memory_level.setter
    def gzip_memory_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gzip_memory_level", value)

    @property
    @pulumi.getter(name="gzipWindowSize")
    def gzip_window_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        """
        return pulumi.get(self, "gzip_window_size")

    @gzip_window_size.setter
    def gzip_window_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gzip_window_size", value)

    @property
    @pulumi.getter(name="keepAcceptEncoding")
    def keep_accept_encoding(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        """
        return pulumi.get(self, "keep_accept_encoding")

    @keep_accept_encoding.setter
    def keep_accept_encoding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "keep_accept_encoding", value)

    @property
    @pulumi.getter(name="uriExcludes")
    def uri_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        """
        return pulumi.get(self, "uri_excludes")

    @uri_excludes.setter
    def uri_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "uri_excludes", value)

    @property
    @pulumi.getter(name="uriIncludes")
    def uri_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        """
        return pulumi.get(self, "uri_includes")

    @uri_includes.setter
    def uri_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "uri_includes", value)

    @property
    @pulumi.getter(name="varyHeader")
    def vary_header(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        return pulumi.get(self, "vary_header")

    @vary_header.setter
    def vary_header(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vary_header", value)


@pulumi.input_type
class _ProfileHttpCompressState:
    def __init__(__self__, *,
                 compression_buffersize: Optional[pulumi.Input[int]] = None,
                 content_type_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 content_type_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cpu_saver: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 gzip_compression_level: Optional[pulumi.Input[int]] = None,
                 gzip_memory_level: Optional[pulumi.Input[int]] = None,
                 gzip_window_size: Optional[pulumi.Input[int]] = None,
                 keep_accept_encoding: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vary_header: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProfileHttpCompress resources.
        :param pulumi.Input[int] compression_buffersize: Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_excludes: Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_includes: Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[str] cpu_saver: Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[int] gzip_compression_level: Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        :param pulumi.Input[int] gzip_memory_level: Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        :param pulumi.Input[int] gzip_window_size: Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        :param pulumi.Input[str] keep_accept_encoding: Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        :param pulumi.Input[str] name: Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_excludes: Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_includes: Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        :param pulumi.Input[str] vary_header: Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        if compression_buffersize is not None:
            pulumi.set(__self__, "compression_buffersize", compression_buffersize)
        if content_type_excludes is not None:
            pulumi.set(__self__, "content_type_excludes", content_type_excludes)
        if content_type_includes is not None:
            pulumi.set(__self__, "content_type_includes", content_type_includes)
        if cpu_saver is not None:
            pulumi.set(__self__, "cpu_saver", cpu_saver)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if gzip_compression_level is not None:
            pulumi.set(__self__, "gzip_compression_level", gzip_compression_level)
        if gzip_memory_level is not None:
            pulumi.set(__self__, "gzip_memory_level", gzip_memory_level)
        if gzip_window_size is not None:
            pulumi.set(__self__, "gzip_window_size", gzip_window_size)
        if keep_accept_encoding is not None:
            pulumi.set(__self__, "keep_accept_encoding", keep_accept_encoding)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if uri_excludes is not None:
            pulumi.set(__self__, "uri_excludes", uri_excludes)
        if uri_includes is not None:
            pulumi.set(__self__, "uri_includes", uri_includes)
        if vary_header is not None:
            pulumi.set(__self__, "vary_header", vary_header)

    @property
    @pulumi.getter(name="compressionBuffersize")
    def compression_buffersize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        """
        return pulumi.get(self, "compression_buffersize")

    @compression_buffersize.setter
    def compression_buffersize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "compression_buffersize", value)

    @property
    @pulumi.getter(name="contentTypeExcludes")
    def content_type_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        """
        return pulumi.get(self, "content_type_excludes")

    @content_type_excludes.setter
    def content_type_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "content_type_excludes", value)

    @property
    @pulumi.getter(name="contentTypeIncludes")
    def content_type_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        """
        return pulumi.get(self, "content_type_includes")

    @content_type_includes.setter
    def content_type_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "content_type_includes", value)

    @property
    @pulumi.getter(name="cpuSaver")
    def cpu_saver(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        """
        return pulumi.get(self, "cpu_saver")

    @cpu_saver.setter
    def cpu_saver(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cpu_saver", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="gzipCompressionLevel")
    def gzip_compression_level(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        """
        return pulumi.get(self, "gzip_compression_level")

    @gzip_compression_level.setter
    def gzip_compression_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gzip_compression_level", value)

    @property
    @pulumi.getter(name="gzipMemoryLevel")
    def gzip_memory_level(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        """
        return pulumi.get(self, "gzip_memory_level")

    @gzip_memory_level.setter
    def gzip_memory_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gzip_memory_level", value)

    @property
    @pulumi.getter(name="gzipWindowSize")
    def gzip_window_size(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        """
        return pulumi.get(self, "gzip_window_size")

    @gzip_window_size.setter
    def gzip_window_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gzip_window_size", value)

    @property
    @pulumi.getter(name="keepAcceptEncoding")
    def keep_accept_encoding(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        """
        return pulumi.get(self, "keep_accept_encoding")

    @keep_accept_encoding.setter
    def keep_accept_encoding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "keep_accept_encoding", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="uriExcludes")
    def uri_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        """
        return pulumi.get(self, "uri_excludes")

    @uri_excludes.setter
    def uri_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "uri_excludes", value)

    @property
    @pulumi.getter(name="uriIncludes")
    def uri_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        """
        return pulumi.get(self, "uri_includes")

    @uri_includes.setter
    def uri_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "uri_includes", value)

    @property
    @pulumi.getter(name="varyHeader")
    def vary_header(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        return pulumi.get(self, "vary_header")

    @vary_header.setter
    def vary_header(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vary_header", value)


class ProfileHttpCompress(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compression_buffersize: Optional[pulumi.Input[int]] = None,
                 content_type_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 content_type_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cpu_saver: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 gzip_compression_level: Optional[pulumi.Input[int]] = None,
                 gzip_memory_level: Optional[pulumi.Input[int]] = None,
                 gzip_window_size: Optional[pulumi.Input[int]] = None,
                 keep_accept_encoding: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vary_header: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ltm.ProfileHttpCompress`  Virtual server HTTP compression profile configuration

        Resources should be named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `/Common/test/my-httpcompresprofile`)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        sjhttpcompression = f5bigip.ltm.ProfileHttpCompress("sjhttpcompression",
            name="/Common/sjhttpcompression2",
            defaults_from="/Common/httpcompression",
            uri_excludes=[
                "www.abc.f5.com",
                "www.abc2.f5.com",
            ],
            uri_includes=["www.xyzbc.cisco.com"],
            content_type_includes=["nicecontent.com"],
            content_type_excludes=["nicecontentexclude.com"])
        ```

        ## Import

        BIG-IP LTM HTTP Compress profiles can be imported using the `name`, e.g.

        ```sh
        $ pulumi import f5bigip:ltm/profileHttpCompress:ProfileHttpCompress test-httpcomprs_import /Common/test-httpcomprs
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] compression_buffersize: Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_excludes: Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_includes: Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[str] cpu_saver: Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[int] gzip_compression_level: Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        :param pulumi.Input[int] gzip_memory_level: Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        :param pulumi.Input[int] gzip_window_size: Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        :param pulumi.Input[str] keep_accept_encoding: Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        :param pulumi.Input[str] name: Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_excludes: Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_includes: Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        :param pulumi.Input[str] vary_header: Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileHttpCompressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileHttpCompress`  Virtual server HTTP compression profile configuration

        Resources should be named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `/Common/test/my-httpcompresprofile`)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        sjhttpcompression = f5bigip.ltm.ProfileHttpCompress("sjhttpcompression",
            name="/Common/sjhttpcompression2",
            defaults_from="/Common/httpcompression",
            uri_excludes=[
                "www.abc.f5.com",
                "www.abc2.f5.com",
            ],
            uri_includes=["www.xyzbc.cisco.com"],
            content_type_includes=["nicecontent.com"],
            content_type_excludes=["nicecontentexclude.com"])
        ```

        ## Import

        BIG-IP LTM HTTP Compress profiles can be imported using the `name`, e.g.

        ```sh
        $ pulumi import f5bigip:ltm/profileHttpCompress:ProfileHttpCompress test-httpcomprs_import /Common/test-httpcomprs
        ```

        :param str resource_name: The name of the resource.
        :param ProfileHttpCompressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileHttpCompressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compression_buffersize: Optional[pulumi.Input[int]] = None,
                 content_type_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 content_type_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cpu_saver: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 gzip_compression_level: Optional[pulumi.Input[int]] = None,
                 gzip_memory_level: Optional[pulumi.Input[int]] = None,
                 gzip_window_size: Optional[pulumi.Input[int]] = None,
                 keep_accept_encoding: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vary_header: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileHttpCompressArgs.__new__(ProfileHttpCompressArgs)

            __props__.__dict__["compression_buffersize"] = compression_buffersize
            __props__.__dict__["content_type_excludes"] = content_type_excludes
            __props__.__dict__["content_type_includes"] = content_type_includes
            __props__.__dict__["cpu_saver"] = cpu_saver
            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["gzip_compression_level"] = gzip_compression_level
            __props__.__dict__["gzip_memory_level"] = gzip_memory_level
            __props__.__dict__["gzip_window_size"] = gzip_window_size
            __props__.__dict__["keep_accept_encoding"] = keep_accept_encoding
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["uri_excludes"] = uri_excludes
            __props__.__dict__["uri_includes"] = uri_includes
            __props__.__dict__["vary_header"] = vary_header
        super(ProfileHttpCompress, __self__).__init__(
            'f5bigip:ltm/profileHttpCompress:ProfileHttpCompress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compression_buffersize: Optional[pulumi.Input[int]] = None,
            content_type_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            content_type_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            cpu_saver: Optional[pulumi.Input[str]] = None,
            defaults_from: Optional[pulumi.Input[str]] = None,
            gzip_compression_level: Optional[pulumi.Input[int]] = None,
            gzip_memory_level: Optional[pulumi.Input[int]] = None,
            gzip_window_size: Optional[pulumi.Input[int]] = None,
            keep_accept_encoding: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            uri_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            uri_includes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            vary_header: Optional[pulumi.Input[str]] = None) -> 'ProfileHttpCompress':
        """
        Get an existing ProfileHttpCompress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] compression_buffersize: Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_excludes: Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_type_includes: Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[str] cpu_saver: Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[int] gzip_compression_level: Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        :param pulumi.Input[int] gzip_memory_level: Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        :param pulumi.Input[int] gzip_window_size: Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        :param pulumi.Input[str] keep_accept_encoding: Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        :param pulumi.Input[str] name: Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_excludes: Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] uri_includes: Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        :param pulumi.Input[str] vary_header: Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileHttpCompressState.__new__(_ProfileHttpCompressState)

        __props__.__dict__["compression_buffersize"] = compression_buffersize
        __props__.__dict__["content_type_excludes"] = content_type_excludes
        __props__.__dict__["content_type_includes"] = content_type_includes
        __props__.__dict__["cpu_saver"] = cpu_saver
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["gzip_compression_level"] = gzip_compression_level
        __props__.__dict__["gzip_memory_level"] = gzip_memory_level
        __props__.__dict__["gzip_window_size"] = gzip_window_size
        __props__.__dict__["keep_accept_encoding"] = keep_accept_encoding
        __props__.__dict__["name"] = name
        __props__.__dict__["uri_excludes"] = uri_excludes
        __props__.__dict__["uri_includes"] = uri_includes
        __props__.__dict__["vary_header"] = vary_header
        return ProfileHttpCompress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compressionBuffersize")
    def compression_buffersize(self) -> pulumi.Output[int]:
        """
        Specifies the maximum number of compressed bytes that the system buffers before inserting a Content-Length header (which specifies the compressed size) into the response. The default is `4096` bytes.
        """
        return pulumi.get(self, "compression_buffersize")

    @property
    @pulumi.getter(name="contentTypeExcludes")
    def content_type_excludes(self) -> pulumi.Output[Sequence[str]]:
        """
        Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        """
        return pulumi.get(self, "content_type_excludes")

    @property
    @pulumi.getter(name="contentTypeIncludes")
    def content_type_includes(self) -> pulumi.Output[Sequence[str]]:
        """
        Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        """
        return pulumi.get(self, "content_type_includes")

    @property
    @pulumi.getter(name="cpuSaver")
    def cpu_saver(self) -> pulumi.Output[str]:
        """
        Specifies, when checked (enabled), that the system monitors the percent CPU usage and adjusts compression rates automatically when the CPU usage reaches either the CPU Saver High Threshold or the CPU Saver Low Threshold. The default is `enabled`.
        """
        return pulumi.get(self, "cpu_saver")

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[str]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter(name="gzipCompressionLevel")
    def gzip_compression_level(self) -> pulumi.Output[int]:
        """
        Specifies the degree to which the system compresses the content. Higher compression levels cause the compression process to be slower. The default is 1 - Least Compression (Fastest)
        """
        return pulumi.get(self, "gzip_compression_level")

    @property
    @pulumi.getter(name="gzipMemoryLevel")
    def gzip_memory_level(self) -> pulumi.Output[int]:
        """
        Specifies the number of bytes of memory that the system uses for internal compression buffers when compressing a server response. The default is `8 kilobytes/8192 bytes`.
        """
        return pulumi.get(self, "gzip_memory_level")

    @property
    @pulumi.getter(name="gzipWindowSize")
    def gzip_window_size(self) -> pulumi.Output[int]:
        """
        Specifies the number of kilobytes in the window size that the system uses when compressing a server response. The default is `16` kilobytes
        """
        return pulumi.get(self, "gzip_window_size")

    @property
    @pulumi.getter(name="keepAcceptEncoding")
    def keep_accept_encoding(self) -> pulumi.Output[str]:
        """
        Specifies, when checked (enabled), that the system does not remove the Accept-Encoding: header from an HTTP request. The default is `disabled`.
        """
        return pulumi.get(self, "keep_accept_encoding")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the LTM http compress profile,named with their `full path`.The full path is the combination of the `partition + name` (example: `/Common/my-httpcompresprofile` ) or  `partition + directory + name` of the resource  (example: `my-httpcompresprofile`)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="uriExcludes")
    def uri_excludes(self) -> pulumi.Output[Sequence[str]]:
        """
        Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        """
        return pulumi.get(self, "uri_excludes")

    @property
    @pulumi.getter(name="uriIncludes")
    def uri_includes(self) -> pulumi.Output[Sequence[str]]:
        """
        Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
        """
        return pulumi.get(self, "uri_includes")

    @property
    @pulumi.getter(name="varyHeader")
    def vary_header(self) -> pulumi.Output[str]:
        """
        Specifies, when checked (enabled), that the system inserts a Vary header into cacheable server responses. The default is `enabled`.
        """
        return pulumi.get(self, "vary_header")

